=====
konch
=====

The customizable Python shell
=============================

- **Automatically import** any object upon startup
- **Simple** configuration syntax (it's just Python code)
- **No hard dependencies**
- Uses **IPython** and **BPython** if available, and falls back to built-in interpreter
- Can have multiple configurations per project using **named configs**

.. image:: https://dl.dropboxusercontent.com/u/1693233/github/konchdemo-optim.gif
    :alt: Demo


`http://konch.readthedocs.org <http://konch.readthedocs.org>`_
==============================================================

